/*
 *    TODO.java
 *    Copyright (C) 2000 Stuart Yeates 
 *
 *    This program is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the Free Software
 *    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

// the package we're in
package org.nzdl.gsdl.ptp;

// java standard library classes used
import java.io.IOException;
import java.io.Reader;
import java.io.InputStreamReader;
import java.io.Writer;
import java.io.OutputStreamWriter;
import java.io.BufferedInputStream;
import java.io.BufferedOutputStream;
import java.io.Serializable;
//import java.io.;
import java.util.*;
import java.net.*;

/**
 * Class Locator is an abstract contact details for a digital library
 *
 * Currently implemented Locators include HTTP, IOR and PTP
 *
 * @author stuart yeates (say1@cs.waikato.ac.nz)
 * @version $Revision: 2136 $
 * @see org.nzdl.gsdl.ptp.PTP
 * @see org.nzdl.gsdl.ptp.HTTP
 * @see org.nzdl.gsdl.ptp.IOR
 * 
 */

public abstract class Locator {
  
  /**
   * Convert a Locator from a string into a Locator. 
   * @param the String to be parsed
   * @return null if unable to parse the string, otherwise an instance of a Locator subclass
   */
  static Locator parse(String str) {
    String ptp  = new String("PTP");
    String http = new String("HTTP");
    String ior  = new String("IOR");
    
    String first = str.substring(0,ptp.length());
    if (first.compareToIgnoreCase(ptp) == 0) {
      
      StringBuffer leading = new StringBuffer();
      StringBuffer host = new StringBuffer();
      StringBuffer port = new StringBuffer();
      StringBuffer trailing = new StringBuffer();
      
      int i = 0;
      while(i < str.length() && str.charAt(i) != ':') {
	leading.append(str.charAt(i));
	i++;
      } 
      i++;
      while(i < str.length() && str.charAt(i) != ':') {
	host.append(str.charAt(i));
	i++;
      } 
      i++;
      while(i < str.length() && Character.isDigit(str.charAt(i)) ) {
	port.append(str.charAt(i));
	i++;
      } 
      while(i < str.length() ) {
	trailing.append(str.charAt(i));
	i++;
      } 
      System.err.println("PTP parsed \"" + str + "\" into host = \"" + 
			 host + "\" and port = \"" + port + "\"");
      if (port.equals(""))
	throw new Error ("unable to parse: " +str);
      
      return new PTP(host.toString(),Integer.parseInt(port.toString()));
      
    }
    first = str.substring(0,http.length());
    if (first.compareToIgnoreCase(http) == 0) {
      URL url = null;
      try {
	url = new URL(str);
      } catch (MalformedURLException exception) {
	System.err.println("HTTP: " + str + " threw a MalformedURLException");
	return null;
      }
      if (!(url.getProtocol().compareToIgnoreCase("http") == 0))
	{
	  System.err.println("HTTP: " + str + " not an http url");  
	}
      return new HTTP(url.getHost(),url.getPort(), url.getFile());
    }
    first = str.substring(0,ptp.length());
    if (first.compareToIgnoreCase(ior) == 0) {
      return null;
    }
    return null;
  }
  
}







