/*
 *    P2P.java
 *    Copyright (C) 2000 Stuart Yeates 
 *
 *    This program is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the Free Software
 *    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

// the package we're in
package org.nzdl.gsdl.ptp;

// java standard library classes used
import java.io.IOException;
import java.io.Reader;
import java.io.InputStreamReader;
import java.io.Writer;
import java.io.OutputStreamWriter;
import java.io.BufferedInputStream;
import java.io.BufferedOutputStream;
import java.io.Serializable;
//import java.io.;
import java.util.*;
import java.net.*;

/**
 * Class PTP represents a URL-like connection information to a remote Peer
 *
 * PTP's and connections initiated based on them form the backbone 
 * of the Peer-To-Peer network.
 *
 * @author stuart yeates (say1@cs.waikato.ac.nz)
 * @version $Revision: 2119 $
 * @see org.nzdl.gsdl.ptp.Connection
 * @see Locator
 * @see HTTP
 * @see IOR
 * 
 */

public class PTP extends Locator {
  /** The remote port at which the peer is listening */
  int port;
  /** The host on which the peer is resident */
  String host;
  
  /** The basic constructor */
  PTP(String host, int port) {
    this.host = host;
    this.port = port;
  }
  /** the no-arguments constructor */
  protected PTP() {
    this.host = "";
    this.port = 0;
  }

  /** convert the PTP to a string suitable for parsing later on ...*/
  public String toString() {
    return "PTP:" + host + ":" + port;
  }

}


